'''
Chosen is a JavaScript plugin that makes long,
unwieldy select boxes much more user-friendly.

For more information about Chosen, see:
http://harvesthq.github.com/chosen/
'''

from widgets import *